<?php

declare(strict_types=1);

namespace Drupal\component_library\Twig;

use Drupal\component_library\Entity\ComponentOverride;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\workspaces\WorkspaceManagerInterface;
use Twig\Error\LoaderError;
use Twig\Loader\LoaderInterface;
use Twig\Source;

/**
 * Component Override twig template loader.
 */
class WorkspaceAwareLoader extends Loader {

  /**
   * The workspace manager service.
   *
   * @var \Drupal\workspaces\WorkspaceManagerInterface
   */
  protected $workspaceManager;

  public function __construct(EntityTypeManagerInterface $entityTypeManager, ThemeManagerInterface $theme_manager, WorkspaceManagerInterface $workspace_manager) {
    parent::__construct($entityTypeManager, $theme_manager);
    $this->workspaceManager = $workspace_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheKey($name): string {
    $workspace = \Drupal::service('workspaces.manager')->getActiveWorkspace();
    return $workspace ? $name . '__' . $workspace->id() : $name;
  }

}
